# kdp-python-connector

## Prequisites
* Python version 3.8.5
* Install dependencies from main directory with:
```
pip3 install -r requirements.txt
```
## Release

## Examples
For code examples using kdp-python-connector see github https://github.com/Koverse/kdp-examples
